# Built-in drivers

1. [DS18B20](http://datasheets.maximintegrated.com/en/ds/DS18B20.pdf) Programmable
Resolution [1-Wire](http://en.wikipedia.org/wiki/1-Wire) Digital Thermometer.
2. [AT24CXX](http://www.atmel.com/products/Memories/serial/i2c.aspx) Serial
[EEPROM](http://en.wikipedia.org/wiki/EEPROM).
3. [DS1307](http://datasheets.maximintegrated.com/en/ds/DS1307.pdf)
[Realtime clock](http://en.wikipedia.org/wiki/Real-time_clock) with RAM.
4. [PCF8591](http://www.nxp.com/documents/data_sheet/PCF8591.pdf) 2-Wire 8-bit A/D
and D/A converter.
5. [ADXL345](http://www.analog.com/static/imported-files/data_sheets/ADXL345.pdf)
Digital Accelerometer.
6. [nRF24L01](http://www.nordicsemi.com/eng/Products/2.4GHz-RF/nRF24L01) Single
Chip 2.4GHz Transceiver. 
7. [DHT11](http://www.micro4you.com/files/sensor/DHT11.pdf) Humidity & Temperature
Sensor.
8. [HC-SR04/US-020](http://www.micropik.com/PDF/HCSR04.pdf) Ultrasonic range module.
9. [ST7735](ftp://imall.iteadstudio.com/IM120419001_ITDB02_1.8SP/DS_ST7735.pdf), 262K
Color Single-Chip TFT Controller.
10. [PCD8544](https://www.sparkfun.com/datasheets/LCD/Monochrome/Nokia5110.pdf) 48x84
pixels matrix LCD controller/driver.
11. [TSOP4838](http://www.vishay.com/docs/82459/tsop48.pdf) IR Receiver Modules for
Remote Control Systems.
12. [Virtual Wire (VWI)](http://www.airspayce.com/mikem/arduino/VirtualWire/) on
RF315/433 modules.
13. [HMC5883L](http://www51.honeywell.com/aero/common/documents/myaerospacecatalog-documents/Defense_Brochures-documents/HMC5883L_3-Axis_Digital_Compass_IC.pdf) 3-Axis Digital Compass IC.
14. [NEXA/HomeEasy](http://www.homeeasy.eu/) Wireless Remote command transmitter/receiver
for RF433.
15. [ST7565](http://akizukidenshi.com/download/ds/sitronix/st7565r.pdf), 65x132 Dot
Matrix LCD Controller/Driver.
16. [Touch capacitive sensor](http://en.wikipedia.org/wiki/Capacitive_sensing), debounced
button and keypad.
17. Dials with [Rotary Encoder](http://en.wikipedia.org/wiki/Rotary_encoder).
18. [HD44780](https://www.sparkfun.com/datasheets/LCD/HD44780.pdf) (aka 1602, 2004)
LCD Controller/Driver.
19. [DS3231](http://www.maximintegrated.com/datasheet/index.mvp/id/4627), Extremely
Accurate I2C-Integrated RTC/TCXO/Crystal. 
20. [PCF8574/PCF8574A](http://www.nxp.com/documents/data_sheet/PCF8574.pdf)
Remote 8-bit I/O expander for I2C-bus with interrupt. 
21. [BMP085](https://www.sparkfun.com/datasheets/Components/General/BST-BMP085-DS000-05.pdf)
Digital Pressure Sensor.
22. [TI CC1101](http://www.ti.com/lit/ds/symlink/cc1101.pdf) Low-Power Sub-1 GHz RF
Transceiver.
23. [L3G4200D](http://dlnmh9ip6v2uc.cloudfront.net/datasheets/Sensors/Gyros/3-Axis/CD00265057.pdf)
Digital Gryposcope.
24. [MPU6050](http://dlnmh9ip6v2uc.cloudfront.net/datasheets/Components/General%20IC/PS-MPU-6000A.pdf)
Motion Processing Unit; Digital thermometer, accelerometer and gyroscope.
25. [DS1302](http://datasheets.maximintegrated.com/en/ds/DS1302.pdf) Tickle-Charge
Timekeeping Chip.
26. SD card, [SPI](http://fr.wikipedia.org/wiki/Serial_Peripheral_Interface) driver.
27. [RS485](http://en.wikipedia.org/wiki/RS-485) support; master-slave protocol.
28. [RFM69W/HW](http://www.hoperf.com/upload/rf/RFM69W-V1.3.pdf) [ISM](http://en.wikipedia.org/wiki/ISM_band) Transceiver Module.
29. [W5100](https://www.sparkfun.com/datasheets/DevTools/Arduino/W5100_Datasheet_v1_1_6.pdf)
Ethernet Controller device driver.
30. Slave device support for [SPI](http://fr.wikipedia.org/wiki/Serial_Peripheral_Interface), TWI and [OWI](http://en.wikipedia.org/wiki/1-Wire).

